==> indigitall_flutter_plugin-0.5.0.tar.gz: lib/push/models/Device.dart <==
import 'dart:convert';

import 'package:indigitall_flutter_plugin/push/models/ExternalApp.dart';

class Device {
  /// String field name enable
  static const String _MAP_ENABLE = "enable";

  /// String field name device id
  static const String _MAP_DEVICE_ID = "deviceId";

  /// String field name push token
  static const String _MAP_PUSH_TOKEN = "pushToken";

  /// String field name platform
  static const String _MAP_PLATFORM = "platform";

  /// String field name version
  static const String _MAP_VERSION = "version";

  /// String field name product name
  static const String _MAP_PRODUCT_NAME = "productName";

  /// String field name product version
  static const String _MAP_PRODUCT_VERSION = "productVersion";

  /// String field name os name
  static const String _MAP_OS_NAME = "osName";

  /// String field name os version
  static const String _MAP_OS_VERSION = "osVersion";

  /// String field name device brand
  static const String _MAP_DEVICE_BRAND = "deviceBrand";

  /// String field name device model
  static const String _MAP_DEVICE_MODEL = "deviceModel";

  /// String field name operator
  static const String _MAP_OPERATOR = "operator";

  /// String field name device type
  static const String _MAP_DEVICE_TYPE = "deviceType";

  /// String field name app version
  static const String _MAP_APP_VERSION = "appVersion";

  /// String field name locale
  static const String _MAP_LOCALE = "locale";

  /// String field name time zone
  static const String _MAP_TIME_ZONE = "timeZone";

  /// String field name time offset
  static const String _MAP_TIME_OFFSET = "timeOffset";

  /// String field name external apps
  static const String _MAP_EXTERNAL_APPS = "externalApps";

  /// String field name external code
  static const String _MAP_EXTERNAL_CODE = "externalCode";

  /// device id
  String? deviceId;

  /// if device is enabled
  bool isEnabled = false;

  /// push token
  String? pushToken;

  /// platform of device
  String? platform;

  ///  version
  String? version;

  /// product name
  String? productName;

  /// product version
  String? productVersion;

  /// os name
  String? osName;

  /// os version
  String? osVersion;

  ///  device brand
  String? deviceBrand;

  /// device model
  String? deviceModel;

  /// operator if is disponsable
  String? operator;

  /// device type
  String? deviceType;

  /// app version
  String? appVersion;

  /// locale time
  String? locale;

  /// time zone
  String? timeZone;

  /// time offset
  int? timeOffset;

  /// external apps can open in action
  List<ExternalApp>? externalApps;

  /// external code if was set
  String? externalCode;

  /// Constructo of [Device]
  Device(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _MAP_ENABLE:
          isEnabled = value.toString() == "true";
          break;
        case _MAP_DEVICE_ID:
          deviceId = value.toString();
          break;
        case _MAP_PUSH_TOKEN:
          pushToken = value.toString();
          break;
        case _MAP_PLATFORM:
          platform = value.toString();
          break;
        case _MAP_VERSION:
          version = value.toString();
          break;
        case _MAP_PRODUCT_NAME:
          productName = value.toString();
          break;
        case _MAP_PRODUCT_VERSION:
          productVersion = value.toString();
          break;
        case _MAP_OS_NAME:
          osName = value.toString();
          break;
        case _MAP_OS_VERSION:
          osVersion = value.toString();
          break;
        case _MAP_DEVICE_BRAND:
          deviceBrand = value.toString();
          break;
        case _MAP_DEVICE_MODEL:
          deviceModel = value.toString();
          break;
        case _MAP_OPERATOR:
          operator = value.toString();
          break;
        case _MAP_DEVICE_TYPE:
          deviceType = value.toString();
          break;
        case _MAP_APP_VERSION:
          appVersion = value.toString();
          break;
        case _MAP_LOCALE:
          locale = value.toString();
          break;
        case _MAP_TIME_ZONE:
          timeZone = value.toString();
          break;
        case _MAP_TIME_OFFSET:
          timeOffset = int.parse(value.toString());
          break;
        case _MAP_EXTERNAL_CODE:
          externalCode = value.toString();
          break;
        case _MAP_EXTERNAL_APPS:
          {
            String externalAppsString = value.toString();
            externalApps = ExternalApp.createArray(externalAppsString);
          }
          break;
      }
    });
  }

  /// conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (deviceId != null) map[_MAP_DEVICE_ID] = deviceId;
    map[_MAP_ENABLE] = isEnabled;
    if (pushToken != null) map[_MAP_PUSH_TOKEN] = pushToken;
    if (platform != null) map[_MAP_PLATFORM] = platform;
    if (version != null) map[_MAP_VERSION] = version;
    if (productName != null) map[_MAP_PRODUCT_NAME] = productName;
    if (productVersion != null) map[_MAP_PRODUCT_VERSION] = productVersion;
    if (osName != null) map[_MAP_OS_NAME] = osName;
    if (osVersion != null) map[_MAP_OS_VERSION] = osVersion;
    if (deviceBrand != null) map[_MAP_DEVICE_BRAND] = deviceBrand;
    if (deviceModel != null) map[_MAP_DEVICE_MODEL] = deviceModel;
    if (operator != null) map[_MAP_OPERATOR] = operator;
    if (deviceType != null) map[_MAP_DEVICE_TYPE] = deviceType;
    if (appVersion != null) map[_MAP_APP_VERSION] = appVersion;
    if (locale != null) map[_MAP_LOCALE] = locale;
    if (timeZone != null) map[_MAP_TIME_ZONE] = timeZone;
    if (timeOffset != null) map[_MAP_TIME_OFFSET] = timeOffset;
    if (externalApps != null) {
      List<Map> list = [];
      for (var i = 0; i < externalApps!.length; i++) {
        list.add(externalApps![i].toMap());
      }
      map[_MAP_EXTERNAL_APPS] = list;
    }
    if (externalCode != null) map[_MAP_EXTERNAL_CODE] = externalCode;
    return map;
  }

  /// Conversion to [String]
  @override
  String toString() {
    return json.encode(toMap());
  }
}

==> indigitall_flutter_plugin-2.1.3.tar.gz: lib/push/models/Device.dart <==
import 'dart:convert';

import 'package:indigitall_flutter_plugin/push/models/ExternalApp.dart';

class Device {
  /// String field name enable
  static const String _MAP_ENABLE = "enable";

  /// String field name device id
  static const String _MAP_DEVICE_ID = "deviceId";

  /// String field name push token
  static const String _MAP_PUSH_TOKEN = "pushToken";

  /// String field name platform
  static const String _MAP_PLATFORM = "platform";

  /// String field name version
  static const String _MAP_VERSION = "version";

  /// String field name product name
  static const String _MAP_PRODUCT_NAME = "productName";

  /// String field name product version
  static const String _MAP_PRODUCT_VERSION = "productVersion";

  /// String field name os name
  static const String _MAP_OS_NAME = "osName";

  /// String field name os version
  static const String _MAP_OS_VERSION = "osVersion";

  /// String field name device brand
  static const String _MAP_DEVICE_BRAND = "deviceBrand";

  /// String field name device model
  static const String _MAP_DEVICE_MODEL = "deviceModel";

  /// String field name operator
  static const String _MAP_OPERATOR = "operator";

  /// String field name device type
  static const String _MAP_DEVICE_TYPE = "deviceType";

  /// String field name app version
  static const String _MAP_APP_VERSION = "appVersion";

  /// String field name locale
  static const String _MAP_LOCALE = "locale";

  /// String field name time zone
  static const String _MAP_TIME_ZONE = "timeZone";

  /// String field name time offset
  static const String _MAP_TIME_OFFSET = "timeOffset";

  /// String field name external apps
  static const String _MAP_EXTERNAL_APPS = "externalApps";

  /// String field name external code
  static const String _MAP_EXTERNAL_CODE = "externalCode";

  /// device id
  String? deviceId;

  /// if device is enabled
  bool isEnabled = false;

  /// push token
  String? pushToken;

  /// platform of device
  String? platform;

  ///  version
  String? version;

  /// product name
  String? productName;

  /// product version
  String? productVersion;

  /// os name
  String? osName;

  /// os version
  String? osVersion;

  ///  device brand
  String? deviceBrand;

  /// device model
  String? deviceModel;

  /// operator if is disponsable
  String? operator;

  /// device type
  String? deviceType;

  /// app version
  String? appVersion;

  /// locale time
  String? locale;

  /// time zone
  String? timeZone;

  /// time offset
  int? timeOffset;

  /// external apps can open in action
  List<ExternalApp>? externalApps;

  /// external code if was set
  String? externalCode;

  /// Constructo of [Device]
  Device(Map map) {
    map.forEach((key, value) {
      switch (key) {
        case _MAP_ENABLE:
          isEnabled = value.toString() == "true";
          break;
        case _MAP_DEVICE_ID:
          deviceId = value.toString();
          break;
        case _MAP_PUSH_TOKEN:
          pushToken = value.toString();
          break;
        case _MAP_PLATFORM:
          platform = value.toString();
          break;
        case _MAP_VERSION:
          version = value.toString();
          break;
        case _MAP_PRODUCT_NAME:
          productName = value.toString();
          break;
        case _MAP_PRODUCT_VERSION:
          productVersion = value.toString();
          break;
        case _MAP_OS_NAME:
          osName = value.toString();
          break;
        case _MAP_OS_VERSION:
          osVersion = value.toString();
          break;
        case _MAP_DEVICE_BRAND:
          deviceBrand = value.toString();
          break;
        case _MAP_DEVICE_MODEL:
          deviceModel = value.toString();
          break;
        case _MAP_OPERATOR:
          operator = value.toString();
          break;
        case _MAP_DEVICE_TYPE:
          deviceType = value.toString();
          break;
        case _MAP_APP_VERSION:
          appVersion = value.toString();
          break;
        case _MAP_LOCALE:
          locale = value.toString();
          break;
        case _MAP_TIME_ZONE:
          timeZone = value.toString();
          break;
        case _MAP_TIME_OFFSET:
          timeOffset = int.parse(value.toString());
          break;
        case _MAP_EXTERNAL_CODE:
          externalCode = value.toString();
          break;
        case _MAP_EXTERNAL_APPS:
          {
            String externalAppsString = value.toString();
            externalApps = ExternalApp.createArray(
                "{\"" + key + "\":" + externalAppsString + "}");
          }
          break;
      }
    });
  }

  /// conversion to [Map]
  Map toMap() {
    Map map = Map();
    if (deviceId != null) map[_MAP_DEVICE_ID] = deviceId;
    map[_MAP_ENABLE] = isEnabled;
    if (pushToken != null) map[_MAP_PUSH_TOKEN] = pushToken;
    if (platform != null) map[_MAP_PLATFORM] = platform;
    if (version != null) map[_MAP_VERSION] = version;
    if (productName != null) map[_MAP_PRODUCT_NAME] = productName;
    if (productVersion != null) map[_MAP_PRODUCT_VERSION] = productVersion;
    if (osName != null) map[_MAP_OS_NAME] = osName;
    if (osVersion != null) map[_MAP_OS_VERSION] = osVersion;
    if (deviceBrand != null) map[_MAP_DEVICE_BRAND] = deviceBrand;
    if (deviceModel != null) map[_MAP_DEVICE_MODEL] = deviceModel;
    if (operator != null) map[_MAP_OPERATOR] = operator;
    if (deviceType != null) map[_MAP_DEVICE_TYPE] = deviceType;
    if (appVersion != null) map[_MAP_APP_VERSION] = appVersion;
    if (locale != null) map[_MAP_LOCALE] = locale;
    if (timeZone != null) map[_MAP_TIME_ZONE] = timeZone;
    if (timeOffset != null) map[_MAP_TIME_OFFSET] = timeOffset;
    if (externalApps != null) {
      List<Map> list = [];
      for (var i = 0; i < externalApps!.length; i++) {
        list.add(externalApps![i].toMap());
      }
      map[_MAP_EXTERNAL_APPS] = list;
    }
    if (externalCode != null) map[_MAP_EXTERNAL_CODE] = externalCode;
    return map;
  }

  /// Conversion to [String]
  @override
  String toString() {
    return json.encode(toMap());
  }
}
